<?PHP
/**
 * @version 1.0
 * @copyright Key2Publish
 * @author Jordy Nieland
 */

	//Include getter file
	include('Getters.php');

	/**
	  Upload file

	  @param File $file file to upload
	  @param String $LOCATION location to upload to
	  @param String $FILENAME filename
	  @param String $EXTENTION file format of file
	 */
	function uploadFile($file, $LOCATION, $FILENAME, $EXTENTION){

		$LOCATION = $LOCATION."/".$FILENAME.$EXTENTION;
		move_uploaded_file($file["tmp_name"], $LOCATION);

		return "yes";
	}

	/**
	  Connect Sqlite file with PDO

	  @param String $SQLOCATION Location of sqlite file
	  @param String $SQNAME Name of sqlite file
	  @return PDO $db Sqlite instance
	 */
	function connectSqlite($SQLOCATION, $SQNAME){
		$db = false;
		try{
			//Create PDO for mysql connection
			$db = new PDO('sqlite:'.$SQLOCATION.$SQNAME.'.sqlite');
		}catch(PDOException $e){
			echo $e->getMessage();
		}

		//Return db, can be called in all functions
		return $db;
	}

	/**
	  Return if logged in correctly and credentials are correct

	  @param String $MAGENTO Location of magento classes
	  @param String $username Entered username
	  @param String $password Entered password
	  @return Boolean $loggedin if credentials are correct
	 */
	function loginAdmin($MAGENTO, $username, $password){
		//Require $MAGENTO for model, this way you can call the magento functions
		require_once $MAGENTO;
		umask(0);
		$app = Mage::app('default');
		$error = array();

		Mage::getSingleton('core/session', array('name' => 'adminhtml'));

		// supply username
		$user = Mage::getModel('admin/user'); // user your admin username

		if(!$user->authenticate($username, $password)){
			$error[] = "Username or password is incorrect.";
		}

		if (Mage::getSingleton('adminhtml/url')->useSecretKey()) {
			Mage::getSingleton('adminhtml/url')->renewSecretUrls();
		}

		$session = Mage::getSingleton('admin/session');
		$session->setIsFirstVisit(true);
		$session->setUser($user);
		$session->setAcl(Mage::getResourceModel('admin/acl')->loadAcl());
		Mage::dispatchEvent('admin_session_user_login_success',array('user'=>$user));

		if (count($error) == 0) {
			$loggedin = true;
			Mage::init();;
			Mage::app("default")->setCurrentStore( Mage_Core_Model_App :: ADMIN_STORE_ID );
		} else{
			print_r($error);
			$loggedin = false;
		}
		//Returns boolean whether login data is correct or not
		return $loggedin;
	}

	/**
	 	Function to insert images for a category
	 	@param $filename
	 	@return filename
	 */
	function getCategoryImageFile($filename, $imageUrl){
		if($filename == ""){
			return "";
		}

		$info = pathinfo($filename);
		$picture_name = $info['basename'];

		$filePath = Mage::getBaseDir('media') . DS . 'catalog' . DS . 'category' . DS . $picture_name;
		$imageUrl=file_get_contents($filename);

		if(file_put_contents($filePath, $imageUrl)){
			Mage::log('ERROR: ', null,'error');
		} else{
			Mage::log('Image Created Successfully', null, '');
		}

		return  $picture_name;
	}

	/**
	  Function to export categories into Magento

	  @param array $categories Contains categories from sqlite file
	  @param String $MAGENTO Magento path
	  @param int $START Start of selection
	  @param int $STEPS Amount of steps per post
	  @param array $paths contains category paths
	 */
	function exportCategories($categories, $parents, $MAGENTO, $START, $STEPS, $paths, $path_string){
		$succes = 0;
		$inserted = 0;
		$updated= 0;
		$failed = 0;
		$total = $STEPS;
		//$before = microtime(true);
		//print_r($categories);
		//die;
		//Iterate over $categories array to take each category apart.
		foreach ($categories as $row){
			$path = array();

			//Add root and default category to path.
			$path[] = 1;
			$path[] = 2;

			//Get category path
			foreach($path_string[$row['k2_id']] as $id => $parent){
				if($parent != $path_string[$row['k2_id']][(count($path_string[$row['k2_id']])-1)]){
					$path[] = Mage::getModel('catalog/category')->loadByAttribute('name', $parent)->getId();
				}
			}

			//Implode $path to get categorie ids with / as seperator
			$DIR = implode('/', array_unique($path));


			//echo $row['k2_name'] . " Dir: " . $DIR . "\n";
			//Try to add categorie and set all the data.
			try{
				$category = null;
				$collection = Mage::getModel('catalog/category')->getCollection()->addAttributeToFilter('is_active', array('eq' => 1))->addAttributeToSelect('*')->addAttributeToFilter('name', $row['k2_name']);
				if(count($collection) > 0){
					foreach ($collection as $category_match){
						if($category_match->getParentCategory()->getPath() == implode("/", $path)){
							$category = $category_match;
						}
					}
				}

				//echo "Categorie: " . $general['name'] . ", path: ";print_r($DIR); echo "\n";

				//Check if category exists else update
				if($category == null){
					$category = Mage::getModel('catalog/category');
					$general['k2p_api_index'] = $row['k2_id'];
					$general['path'] = $DIR;
					$general['name'] = $row['k2_name'];
					$general['description'] = $row['k2_description'];
					$general['landing_page'] = '';
					$general['display_mode'] = "PRODUCTS_AND_PAGE"; //static block and the products are shown on the page
					$general['is_active'] = '1';
					$general['is_anchor'] = 0;
					$general['page_layout'] = 'two_columns_left';
					$general['meta_title'] = $row['k2_name'];
					$general['meta_description'] = $row['k2_description'];
					$general['path_string'] = implode("/", $path_string[$row['k2_id']]);

					if($product['k2_picture'] != null && filter_var($product['k2_picture'], FILTER_VALIDATE_URL)) {
						$general['thumbnail'] =	getCategoryImageFile($row['k2_picture']);
					} else{
						$general['thumbnail'] =	$row['k2_picture'];
					}

					//$general['meta_title'] = $_POST['cat_title']; //Page title
					//$general['meta_keywords'] = $_POST['cat_meta_key'];
					//$general['meta_description'] = $_POST['cat_meta_description'];
					//$general['url_key'] = "cars";//url to be used for this category's page by magento.

					$category->addData($general);
					$category->save();
					$inserted += 1;
				} else{
					$DIR = $DIR."/".$category->getId();
					$category->setName($row['k2_name']);
					$category->setData('k2p_api_index', $row['k2_id']);
					$category->setData('path', $DIR);
					$category->setData('path_string', implode("/", $path_string[$row['k2_id']]));
					$category->setDescription($row['k2_description']);
					$category->setMetaDescription($row['k2_description']);
					if($row['k2_picture'] != "" && filter_var($row['k2_picture'], FILTER_VALIDATE_URL) && !file_exists(Mage::getBaseDir('media') . DS . 'catalog' . DS . 'category' . DS . $row['k2_picture'])) {
						$category->setData('thumbnail', getCategoryImageFile($row['k2_picture']));
					} else{
						$category->setData('thumbnail', $row['k2_picture']);
					}
					$updated += 1;
				}

				$category->setStoreId(0); // 0 = default/all store view. If you want to save data for a specific store view, replace 0 by Mage::app()->getStore()->getId().;

				$succes++;
				$category->save();
			} catch(Exception $e){
				//Print if there is an error.
				echo $e;
				$errors = $e;
			}
		}

		//print export data
		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["inserted"] = $inserted;
			$data["result"]["success"]["updated"] = $updated;
			$data["result"]["success"]["failed"] = $total - $inserted - $updated;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);
		//$after = microtime(true);
		//echo ($after-$before) . " sec\n";
		//echo '{"Start":"'.$START.'", "End":"'.($START+count($categories)).'", "Errors":"'.$errors.'", "Succes":"'.$succes.'"}';
	}

	/**
	  Function to delete categories from Magento

	  @param String $MAGENTO Magento path
	  @param array $categories contains categories from sqlite file
	  @param int $START Start of query
	  @param int $STEPS Amount of steps for post
	 */
	function deleteCategories($MAGENTO, $categories, $START, $STEPS, $path_string){

		$deleted = 0;
		$skipped = 0;
		$failed= 0;

		$errors;

		//If $categories has less than 25 categories, adjust $STEPS to get better delete data afterwarts
		if(count($categories < 25)){
			$STEPS = count($categories);
		}
		$total = $STEPS;

		//Iterate over categories and delete categories one by one
		foreach ($categories as $row) {
			try{
				//Add root and default category to path.
    		$path = array();
				$path[] = 1;
				$path[] = 2;

				//Get category path
				foreach($path_string[$row['k2_id']] as $id => $parent){
					if($parent != $path_string[$row['k2_id']][(count($path_string[$row['k2_id']])-1)]){
						if(($parent_obj = Mage::getModel('catalog/category')->loadByAttribute('name', $parent)) != null){
							$path[] = $parent_obj->getId();
						}
					}
				}

				$category = null;
				$collection = Mage::getModel('catalog/category')->getCollection()->addAttributeToFilter('is_active', array('eq' => 1))->addAttributeToSelect('*')->addAttributeToFilter('name', $row['k2_name']);
				if(count($collection) > 0){
					foreach ($collection as $category_match){
						if($category_match->getParentCategory()->getPath() == implode("/", $path)){
							$category = $category_match;
						}
					}
				}

				if($category != null && $category->getProductCount() == 0 && count($category->getChildren) == 0){
				      $category->delete();
              $deleted++;
				} else {
					//echo "Product count: " . $category->getProductCount() . " Children count: " .count($category->getChildren);
					$skipped++;
				}
			} catch(Exception $e) {
				echo $e;
				$errors = $e;
			}
		}

		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["deleted"] = $deleted;
			$data["result"]["success"]["skipped"] = $skipped;
			$data["result"]["success"]["failed"] = $total - $deleted - $skipped;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//print delete data
		///$error = $STEPS-$succes;
		//echo '{"Start":"'.$START.'", "End":"'.($START+$STEPS).'", "Errors":"'.$error.'", "Succes":"'.$succes.'"}';
	}

	/**
	  Function to export products into Magento

	  @param array $products Contains products from Productgroups table in array
	  @param array $categories Contains categories from sqlite
	  @param String $MAGENTO Path to Magento
	  @param int $STEPS Amount of steps for post
	  @param int $START Start of post
	  @param array $datatypes Contains information from datatypes table
	  @param array $children Contains children from configurable products
	  @param array $attributeData Contains attributes
	  @param boolean $VAT Boolean if price is inclusive or exclusive tax
	  @param String $child_sku_hash Holds a String for hashing child sku, it is false when you do not want to hash child
	  @param String $parent_sku_hash Holds a String for hashing parent sku, it is false when you do not want to hash parent product sku
	 */
	function exportProducts($products, $categories, $parents, $MAGENTO, $STEPS, $START, $datatypes, $children, $attributeData, $VAT, $child_sku_hash, $parent_sku_hash, $IMGLOCATION, $TOTALPRODUCTS, $path_string, $simpleattributes){
		$succes = 0;
		$inserted = 0;
		$updated= 0;
		$failed = 0;
		$total = $STEPS;
		$errors;

		$updating = false;

		//Set variables
		$IMGLOCATION = $IMGLOCATION . "product";
		$base_image_folder = $IMGLOCATION.'/';
		$attributes = array();
		$a_data = array();
		$attributeset = 4;
		$quantity = 1111;
		$edited = 0;
		$count = 0;

		foreach($attributeData['attributes'] as $attribute){		//Preload all attributes, these attributes will be used to set attribute values for products.
			$attributes[$attribute['k2_name']] = Mage::getModel('eav/entity_attribute')->loadByCode(Mage_Catalog_Model_Product::ENTITY, $attribute['k2_name']);
		}

		unset($attributeData['attributes']);			//Unset attributeData['attributes'], this holds the attribute names and have no further purpose

		foreach($products as $product){					//Loop over (highest level) products
			$sku_first = $product['k2_productid'];

			//Empty arrays
			$configurableProductsData = array();
			$configurablePrices = array();

			if($children[$product['k2_id']] == null){	//Check if product is simple or configurable
				$type = 'simple';
			} else{
				$type = 'configurable';
				if($parent_sku_hash != false){
					$product['k2_productid'] = $product['k2_productid'].$parent_sku_hash;
				}
			}

			$productId = Mage::getModel('catalog/product')->getIdBySku($product['k2_productid']);		//Init basic variables

			if($productId == null){						//Check if product exists, if not: set $sProduct as new, if it does: Set $sProduct by loading sku
				$sProduct = Mage::getModel('catalog/product');
				$count++;
				$updating = false;
			} else{
				$sProduct = Mage::getModel('catalog/product')->loadByAttribute('sku',$product['k2_productid']);
				$updating = true;
			}

			//Load parent category
			$cat_path = array();

      $path = array();
			$path[] = 1;
			$path[] = 2;
      $parentCategoryId = $product['k2_parent'];
      $root = Mage::getModel('catalog/category')->load(2);
      $children = $root->getChildren();
      foreach($path_string[$parentCategoryId] as $id => $parent){
          foreach(explode(',', $children) as $potentional_group_id){
            $potentional_group = Mage::getModel('catalog/category')->load($potentional_group_id);
            if($potentional_group->getName() == $parent){
								$path[] = $potentional_group->getId();
                $children = $potentional_group->getChildren();
            }
        }
      }

		  // foreach($parents[$product['k2_name']] as $parentId){
			// 	//$category = Mage::getModel('catalog/category')->loadByAttribute('k2p_api_index', $parentId); // Gives error with changed group names. (duplicate k2p_api_index's)
  		// 	$category = Mage::getModel('catalog/category')->loadByAttribute('name', $categories[$parentId]['k2_name']);
			// 	$path = explode("/", $category->getData('path'));
			// 	$cat_path = array_merge($cat_path, $path);	//Get category path and create array
			// }
			// $cat_path = array_unique($cat_path);
      $cat_path = explode("/", $path[ (count($path)-1)]);



			/***********	BEGIN OF PICTURE ***********/
			if($product['k2_picture'] != null and filter_var($product['k2_picture'], FILTER_VALIDATE_URL)){
				$url = $product['k2_picture'];
				$info = pathinfo($url);
				$name = $info['basename'];

				$filePath_image =$name[0].'/'.$name[1].'/'.$name;
			} else{
				$filePath_image = $product['k2_picture'][0].'/'.$product['k2_picture'][1].'/'.$product['k2_picture'];
			}

			//Download image if picture is an url
			if($product['k2_picture'] != null && filter_var($product['k2_picture'], FILTER_VALIDATE_URL)) {
				$url = $product['k2_picture'];
				$info = pathinfo($url);
				$name = $info['basename'];

				//Image upload
				//Create directories
				$first_letter = $name[0];
				$second_letter = $name[1];
				$IMGLOCATION_first = $base_image_folder."/".$first_letter;
				$IMGLOCATION_complete = $base_image_folder."/".$first_letter."/".$second_letter;

				//Create folders if not exists
				if (!file_exists($base_image_folder)) {
					mkdir($base_image_folder);
				}
				if (!file_exists($IMGLOCATION_first)) {
					mkdir($IMGLOCATION_first);
				}
				if (!file_exists($IMGLOCATION_complete)) {
					mkdir($IMGLOCATION_complete);
				}

				$tmp_location = $base_image_folder.$name[0]."/".$name[1]."/".$name;
				file_put_contents($tmp_location, file_get_contents($url));
			}

			//Create tax class if it does not exist and store taxclassid in variable
			if($product['k2_vat'] == "" or $product['k2_vat'] == 0){
				$taxClassId = 0;
			} else{
				$taxClassId = createTaxClass($product['k2_vat']);
				if($VAT == 1){
					//Calculate price excl btw
					$product['k2_price'] = $product['k2_price']/(1+($product['k2_vat']/100));
				}
			}

			//Set basic values for configurable/simple product
			try{
				$productData=array(
							'name' => $product['k2_name'],
							'sku' => $product['k2_productid'],
							'description' => $product['k2_description'],
							'short_description' => $product['k2_description'],
							'weight' => 100, // whatever your product weighs
							'status' => 1, // 1 => enabled, 0 => disabled
							'visibility' => 4, // 1 => Not Visible Individually, 2 => Catalog, 3 => Search, 4 => Catalog, Search
							'attribute_set_id' => $attributeset, // default
							'type_id' => $type,
							'price' => $product['k2_price'],
							//'special_price' => $product['k2_price'], // optional
							'tax_class_id' => $taxClassId, // None
							'k2p_order_id' => $product['k2_ordernr'],
							'qty' => $quantity,
							//'image' => $filePath_image,
							//'small_image' => $filePath_image,
							//'thumbnail' => $filePath_image
				);

				// traversing through each index of productData
				foreach($productData as $key => $value){
					$sProduct->setData($key,$value);
				}

				foreach($simpleattributes[$product["k2_id"]] as $option){
					$attrValueId = attributeValueExists($option["k2_name"], $option["k2_value"]);
					if($attrValueId){
						$sProduct->setData($option["k2_name"], $attrValueId);
					}
				}

				//Set attribute values for (highest level) product(s)
				foreach($attributeData[$sku_first] as $a_data){
						$attributeObject = $attributes[$a_data['k2_name']];
						$option_id = $attributeObject->getSource()->getOptionId($a_data['k2_value']);
						$sProduct->setData($a_data['k2_name'], $option_id);
				}

				$sProduct->setWebsiteIDs(array(1)); # Website id, 1 is default
				$sProduct->setAttributeSetId($attributeset); // 4 means Default AttributeSet
				$sProduct->setCategoryIds($path);

				$sProduct->save();

				//Set inventory if this is a simple product
				if($type=='simple'){
					//Enter stock data
					$stockItem = Mage::getModel('cataloginventory/stock_item');
					$stockItem->assignProduct($sProduct);
					$stockItem->setData('is_in_stock', 1);
					$stockItem->setData('stock_id', 1);
					$stockItem->setData('store_id', 0);
					$stockItem->setData('manage_stock', 1);
					$stockItem->setData('use_config_manage_stock', 0);
					$stockItem->setData('min_sale_qty', 0);
					$stockItem->setData('use_config_min_sale_qty', 0);
					$stockItem->setData('max_sale_qty', 1000);
					$stockItem->setData('use_config_max_sale_qty', 0);
					$stockItem->setData('qty', $quantity);
					$stockItem->save();
				}

				if ($updating) {
					$updated += 1;
				} else {
					$inserted += 1;
				}

			} catch(Exception $e){
				$errors .= "Configurable product setup error: ".$e;
				//print_r($product);
			}

			if($type == 'configurable'){
				$p_id = $product['k2_id'];
				//Export child products
				foreach($children[$p_id] as $product_child){
					$total++;
					try{
						$child_old_sku = $product_child['k2_productid'];		//used for attribute
						if($child_sku_hash != false){
							$product_child['k2_productid'] = $product_child['k2_productid'].$child_sku_hash;
						}

						$productId = Mage::getModel('catalog/product')->getIdBySku($product_child['k2_productid']);
						$category = Mage::getResourceModel('catalog/category_collection')->addFieldToFilter('k2p_api_index', $categories[$product_child['k2_parent']]['k2_id'])->getData();

						//Check if product exists, if not: set $cProduct as new, if it does: Set $cProduct by loading sku
						if($productId == null){
							$cProduct = Mage::getModel('catalog/product');
							$child_creation = true;
						} else{
							$cProduct = Mage::getModel('catalog/product')->loadByAttribute('sku', $product_child['k2_productid']);
							$child_creation = false;
						}

						$productData=array(
									'name' => $product_child['k2_name'],
									'sku' => $product_child['k2_productid'],
									'description' => $product_child['k2_description'],
									'short_description' => $product_child['k2_description'],
									'weight' => 100, // whatever your product weighs
									'status' => 1, // 1 => enabled, 0 => disabled
									'visibility' => 1, // 1 => Not Visible Individually, 2 => Catalog, 3 => Search, 4 => Catalog, Search
									'attribute_set_id' => $attributeset, // default
									'type_id' => 'simple',
									'price' => $product_child['k2_price'],
					 				//'special_price' => $product_child['k2_price'], // optional
									'tax_class_id' => 0, // None
									'qty' => $quantity
						);

						//traversing through each index of productData
					    foreach($productData as $key => $value){
							$cProduct->setData($key,$value);
						}

						//Set attribute values for child products
					    foreach($attributeData[$child_old_sku] as $a_data){
								$attributeObject = $attributes[$a_data['k2_name']];
								$option_id = $attributeObject->getSource()->getOptionId($a_data['k2_value']);

								$cProduct->setData($a_data['k2_name'], $option_id);
							}


						$cProduct->setCategoryIds(array(2, $category[0][entity_id]));
						$cProduct->setAttributeSetId($attributeset); // 4 means Default AttributeSet
				    	$cProduct->setWebsiteIDs(array(1)); # Website id, 1 is default

						//Get created attribute id and name and update product value of the attribute
						$get_datatype_sku = $datatypes[$child_old_sku]; // 0 = name, 1 = value (array)
						$attr_var = $attributes[$get_datatype_sku['0']];
						if ($attr_var->usesSource()) {
							$a_id = $attr_var->getSource()->getOptionId(trim($get_datatype_sku['1']));
						}

						//Set attribute
						$sProduct->getTypeInstance()->setUsedProductAttributeIds(array($attr_var->getId()));
						$cProduct->save();

						if (!$child_creation) {
							$updated += 1;
						} else {
							$inserted += 1;
						}
					} catch(Exception $e){
						echo $e;
						$errors .= "Child product error (child product setup): ".$e;
						//print_r($product_child);
					}

					//Variation information!
					$option_price = $cProduct->getPrice()-$sProduct->getPrice();	//Diffrence between configurable product price and simple product price
					if($child_creation == true){
						$configurableProductsData[$cProduct->getId()] = array( //id of simple product associated with this configurable
							'label' => $get_datatype_sku['0'],
							'attribute_id' => $attr_var->getId(),
							'value_index'   => $a_id,
							'is_percent'    => '0',
							'pricing_value' => $option_price
						);
					} else{
						updateVariationPrice($sProduct->getId(), $option_price, $a_id);
					}

					//Set data for child product that needs to be added last
					try{
						//Enter stock data
					  $stockItem = Mage::getModel('cataloginventory/stock_item');
						$stockItem->assignProduct($cProduct);
						$stockItem->setData('is_in_stock', 1);
						$stockItem->setData('stock_id', 1);
						$stockItem->setData('store_id', 0);
						$stockItem->setData('manage_stock', 1);
						$stockItem->setData('use_config_manage_stock', 0);
						$stockItem->setData('min_sale_qty', 0);
						$stockItem->setData('use_config_min_sale_qty', 0);
						$stockItem->setData('max_sale_qty', 1000);
						$stockItem->setData('use_config_max_sale_qty', 0);
						$stockItem->setData('qty', $quantity);
						$stockItem->save();
						$cProduct->save();
					} catch(Exception $e){
						echo $e;
						$errors .= "Child product StockItem error: ".$e;
						//print_r($product_child);
					}
				}
			}

			if(file_exists($base_image_folder.$filePath_image) && $product['k2_picture'] != ''){
				$sProduct->addImageToMediaGallery($base_image_folder.$filePath_image, array('image', 'small_image', 'thumbnail'), true, true);
				if($type == 'simple'){
					$sProduct->save();
				}
			}

			//Set configurable data for configurable product (assign child products and save the product data)
			if($type == 'configurable'){
				try{

						$configurableAttributesData = $sProduct->getTypeInstance()->getConfigurableAttributesAsArray();
						if (!empty($configurableProductsData)) {
						$configurableAttributesData[0][values] = $configurableProductsData;
						$sProduct->setConfigurableProductsData($configurableProductsData);
						}
						$sProduct->setConfigurableAttributesData($configurableAttributesData);
						$sProduct->setCanSaveConfigurableAttributes();
						$sProduct->save();
				} catch(Exception $e){
					echo $e;
					$errors .= $e;
				}

				try{
					//Set inventory/stock data for (highest level) product
					$sProduct = Mage::getModel('catalog/product')->loadByAttribute('sku',$product['k2_productid']);

					if (!($stockItem = $sProduct->getStockItem())) {
						$stockItem = Mage::getModel('cataloginventory/stock_item');
						$stockItem->assignProduct($sProduct)->setData('stock_id', 1);
						$stockItem->setData('store_id', 1);
					}

					$stockItem->setData('is_in_stock', 1);
					$stockItem->setData('manage_stock', 1);
					$stockItem->setData('enable_qty_increments', false);
					$stockItem->setData('use_config_qty_increments', false);
					$stockItem->setData('use_config_manage_stock', 0);
					$stockItem->save();
					$sProduct->save();
				} catch(Exception $e){
					echo $e;
				}
			}
		}

		if($START+$STEPS == $TOTALPRODUCTS){
			try {
				$indexer = Mage::getModel('index/indexer')->getProcessByCode('catalog_product_flat');
				$indexer->reindexEverything();
			} catch (Exception $e) { echo $e; }
		}

		//Print product export data
		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["inserted"] = $inserted;
			$data["result"]["success"]["updated"] = $updated;
			$data["result"]["success"]["failed"] = $total - $inserted - $updated;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}



		echo json_encode($data["result"]);
		//$errors = $STEPS-$count-$edited;
		//echo '{"Start":"'.$START.'", "End":"'.($START+count($products)).'", "Errors":"'.$errors.'", "Succes":"'.$count.'"}';
	}

	/**
	  Function to delete products

	  @param String $MAGENTO Magento path
	  @param array $products Contains products from productgroups
	  @param int $STEPS Amount of steps for post
	  @param int $START Start of post
	  @param array $children Contains children from configurable products
	  @param String $child_sku_hash Holds a String for hashing child sku, it is false when you do not want to hash child
	  @param String $parent_sku_hash Holds a String for hashing parent sku, it is false when you do not want to hash parent product sku
	 */
	function deleteProducts($MAGENTO, $products, $STEPS, $START, $children, $child_sku_hash, $parent_sku_hash){
		$deleted	=	0;
		$skipped	=	0;
		$failed		=	0;
		$total		=	$STEPS;
		//Iterate over products and delete them one by one
		foreach ($products as $product) {
			$haschilds = false;
			//Delete child products from configurable product
			foreach($children[$product['k2_id']] as $child){
				if($child_sku_hash != false){
					$child['k2_productid'] = $child['k2_productid'].$child_sku_hash;
				}

				$sProduct = Mage::getModel('catalog/product')->loadByAttribute('sku', $child['k2_productid']);
				if($sProduct != null){
					//Magento function to delete a loaded product
					$sProduct->delete();
				}
				$haschilds = true;
			}

			if($parent_sku_hash != false and $haschilds == true){
				$product['k2_productid'] = $product['k2_productid'].$parent_sku_hash;
			}

			//Delete product (of highest level)
			$products = Mage::getModel('catalog/product')->loadByAttribute('sku', $product['k2_productid']);
			if($products != null){
				//Magento function to delete a loaded product
				$products->delete();
		    	$deleted++;
			} else {
				$skipped++;
			}
		}

		//print product delete data
		//$errors = $STEPS-$succes;

		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["deleted"] = $deleted;
			$data["result"]["success"]["skipped"] = $skipped;
			$data["result"]["success"]["failed"] = $total - $deleted - $skipped;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//echo '{"Start":"'.$START.'", "End":"'.($START+$STEPS).'", "Errors":"'.$error.'", "Succes":"'.$succes.'"}';
	}

	/**
	  Function to check if an attribute value exists

	  @param String $arg_attribute Attriubte name
	  @param String $arg_value Attribute value
	  @return Option value or false whether option value exists or not
	 */
	function attributeValueExists($arg_attribute, $arg_value){
		$attribute_options_model = Mage::getModel('eav/entity_attribute_source_table');
		$attribute = Mage::getModel('catalog/resource_eav_attribute')->loadByCode(Mage_Catalog_Model_Product::ENTITY, $arg_attribute);
		$attribute_table         = $attribute_options_model->setAttribute($attribute);
		$options                 = $attribute_options_model->getAllOptions(false);
		//Iterates over attribute options and checks if option exists
		foreach ($options as $option) {
			if ($option['label'] == $arg_value) {
		       return $option['value'];
			}
		}

		return false;
	}

	/**
	  Function to check if an attribute exists

	  @param String $name Attribute name
	  @return boolean
	 */
	function attributeExists($name){
		$attribute = Mage::getModel('eav/entity_attribute')->getCollection()->addFieldToFilter('attribute_code', $name)->getData();

		if($attribute == null){
			return false;
		} else{
			return true;
		}
	}

	/**
	  Function to export options

	  @param array $options Contains options from sqlite
	 */
	function exportOptions($options){
		//Init params
		$a_added = 0;
		$a_failed = 0;
		$o_added = 0;
		$o_failed = 0;
		$counter = 1;

		$inserted = 0;
		$updated = 0;
		$failed = 0;
		$total = 0;

		//Iterate over options and add one by one if attribute/value does not exist
		foreach($options as $option){
			try{
				if(attributeExists($option['k2_name']) == false){
					createAttribute($option);
					$a_added++;
				}
			} catch(Exception $e){
				$a_failed++;
			}

			addAttributeValue($option['k2_name'], trim($option['k2_value']), $counter, $inserted, $updated);

			$total++;
			$counter=0;
		}

		$attribute = Mage::getModel('catalog/resource_eav_attribute')->loadByCode('catalog_product', $option['k2_name']);
		$attribute->save();
		Mage::getModel('eav/entity_attribute')->getCollection()->addFieldToFilter('attribute_code', $option['k2_name'])->load()->save();

		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["inserted"] = $inserted;
			$data["result"]["success"]["updated"] = $updated;
			$data["result"]["success"]["failed"] = $total - $inserted - $updated;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//Print option export data

		//echo '{"Attributes added":"'.$a_added.'", "Attributes failed":"'.$a_failed.'", "Options added":"'.$o_added.'", "Options failed":"'.$o_failed.'"}';
	}

    /**
      Function to add attribute value

      @param String $attributeCode Attribute name
      @param String $attributeValue Attribute option value name
      @param int $i Is for the position, in magento position cannot be all the same!
     */
	function addAttributeValue($attributeCode, $attributeValue, $i, &$inserted, &$updated){
		// Get Attribute by attribute code
		$attribute = Mage::getModel('catalog/resource_eav_attribute')->loadByCode('catalog_product', $attributeCode);
		// Check if a value exists in Attribute
		if (!attributeValueExists($attributeCode, $attributeValue)) {			// Add Value to option array
			$value['option'] = array($attributeValue);							// Set order for the option
            $order['option'] = $i;												// Assign values to result array
			$result          = array(
				'value' => $value,
				'order' => $order
			);																	// Set attribute data
			$attribute->setData('option', $result);								// Save attribute
			$attribute->save();
			$inserted++;
		} else {
			$updated++;
		}
	}

    /**
      Function to create attribute

      @param array $option Option to add
     */
	function createAttribute($option){
		$global = 'Mage_Catalog_Model_Resource_Eav_Attribute::SCOPE_GLOBAL';

		//Attribute data
		$data = array(
				'is_global'                     => 1,
				'frontend_input'                => select,
				'default_value_text'            => '',
				'default_value_yesno'           => '',
				'default_value_date'            => '',
				'default_value_textarea'        => '',
				'is_unique'                     => 0,
				'is_required'                   => 1,
				'frontend_class'                => '',
				'is_searchable'                 => 0,
				'is_visible_in_advanced_search' => 0,
				'is_comparable'                 => 0,
				'is_used_for_promo_rules'       => 0,
				'is_html_allowed_on_front'      => 0,
				'is_visible_on_front'           => 0,
				'used_in_product_listing'       => 0,
				'used_for_sort_by'              => 0,
				'is_configurable'               => 1,
				'is_filterable'                 => 0,
				'is_filterable_in_search'       => 0,
				'backend_type'                  => 'int',
				'default_value'                 => '',
		);

	    // Valid product types: simple, grouped, configurable, virtual, bundle, downloadable, giftcard
		$data['apply_to']       = array('configurable', 'simple');
		$data['attribute_code'] = $option['k2_name'];
		$data['frontend_label'] = $option['k2_name'];

		$model = Mage::getModel('catalog/resource_eav_attribute');
		$model->addData($data);
		$model->setAttributeSetId(4);
		$model->setAttributeGroupId(7);

		$entityTypeID = Mage::getModel('eav/entity')->setType('catalog_product')->getTypeId();
		$model->setEntityTypeId($entityTypeID);
		$model->setIsUserDefined(1);
		$model->save();
	}

	/**
	  Function to delete options

	  @param array $options Contains options from sqlite
	 */
	function deleteOptions($options){
		$deleted = 0;
		$skipped = 0;
		$failed = 0;
		$total = count($options);

		$attribute = array();

		foreach($options as $option){
			if($attribute[$option['k2_name']] == null){
				$attribute[$option['k2_name']] = Mage::getModel('eav/entity_attribute')->loadByCode(Mage_Catalog_Model_Product::ENTITY, $option['k2_name']);
			}

			if ($attribute[$option['k2_name']]->usesSource()) {
				$option_id = $attribute[$option['k2_name']]->getSource()->getOptionId($option['k2_value']);
				$options['delete'][$option_id] = true;
				$options['value'][$option_id] = true;
				$deleted++;
			} else {
				$skipped++;
			}

			$setup = new Mage_Eav_Model_Entity_Setup('core_setup');
			$setup->addAttributeOption($options);

		}

		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["deleted"] = $deleted;
			$data["result"]["success"]["skipped"] = $skipped;
			$data["result"]["success"]["failed"] = $total - $deleted - $skipped;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//echo 'Options are deleted';
	}

	/**
	  Export manufacturers

	  @param array $manufacturers Contains manufacturers
	 */
	function exportManufacturers($manufacturers){
		//Export attribute if it does not exist yet

		$inserted = 0;
		$updated = 0;
		$failed = 0;
		$total = 1;

		if(attributeExists($manufacturers['name']) == false){
			$global = 'Mage_Catalog_Model_Resource_Eav_Attribute::SCOPE_GLOBAL';
			$data = array(
					'is_global'                     => 1,
					'frontend_input'                => select,
					'default_value_text'            => '',
					'default_value_yesno'           => '',
					'default_value_date'            => '',
					'default_value_textarea'        => '',
					'is_unique'                     => 0,
					'is_required'                   => 0,
					'frontend_class'                => '',
					'is_searchable'                 => 0,
					'is_visible_in_advanced_search' => 0,
					'is_comparable'                 => 0,
					'is_used_for_promo_rules'       => 0,
					'is_html_allowed_on_front'      => 0,
					'is_visible_on_front'           => 1,
					'used_in_product_listing'       => 0,
					'used_for_sort_by'              => 0,
					'is_configurable'               => 0,
					'is_filterable'                 => 0,
					'is_filterable_in_search'       => 0,
					'backend_type'                  => 'int',
					'default_value'                 => '',
			);

		    // Valid product types: simple, grouped, configurable, virtual, bundle, downloadable, giftcard
			$data['apply_to']       = array('configurable', 'simple');
			$data['attribute_code'] = $manufacturers['name'];
			$data['frontend_label'] = $manufacturers['name'];

			$model = Mage::getModel('catalog/resource_eav_attribute');
			$model->addData($data);
			$model->setAttributeSetId(4);
			$model->setAttributeGroupId(7);

			$entityTypeID = Mage::getModel('eav/entity')->setType('catalog_product')->getTypeId();
			$model->setEntityTypeId($entityTypeID);
			$model->setIsUserDefined(1);
			$model->save();
			$inserted += 1;
		} else {
			$updated += 1;
		}

		$attribute = $manufacturers['name'];
		unset($manufacturers['name']);

		//Export manufacturer options
		$counter = 1;
		foreach($manufacturers as $manufacturer){
			addAttributeValue($attribute, $manufacturer, $counter);
			$counter=0;
		}


		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["inserted"] = $inserted;
			$data["result"]["success"]["updated"] = $updated;
			$data["result"]["success"]["failed"] = $total - $inserted - $updated;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//echo 'Manufacturer added';
	}

	/**
	  Function to delete manufacturers

	  @param array $manufacturers Contains manufacturers
	 */
	function deleteManufacturer($manufacturers){
		$deleted = 0;
		$skipped = 0;
		$failed = 0;
		$total = count($manufacturers)-1;

		$attribute = array();

		if($attribute == null){
			$attribute = Mage::getModel('eav/entity_attribute')->loadByCode(Mage_Catalog_Model_Product::ENTITY, $manufacturers['name']);
		}
		unset($manufacturers['name']);

		foreach($manufacturers as $product => $value){

			if ($attribute->usesSource()) {
				$option_id = $attribute->getSource()->getOptionId($value);
				$options['delete'][$option_id] = true;
				$options['value'][$option_id] = true;
			}

			$setup = new Mage_Eav_Model_Entity_Setup('core_setup');
			$setup->addAttributeOption($options);
			$deleted += 1;
		}

		$data = array();
		//$errors = count($categories)-$succes;
		if (!isset($errors)) {
			$data["result"]["success"]["deleted"] = $deleted;
			$data["result"]["success"]["skipped"] = $skipped;
			$data["result"]["success"]["failed"] = $total - $deleted - $skipped;
			$data["result"]["success"]["total"] = $total;
		} else {
			$data["result"]["errors"] = $errors;
		}
		echo json_encode($data["result"]);

		//echo 'Manufacturers are deleted';
	}

	/**
	  Check if tax class exists

	  @param int $rate Tax rate
	 */
	function taxClassExistenceCheck($rate){
		$class_name = "BTW_".$rate;
		$productTaxClass = Mage::getModel('tax/class')
		->getCollection()
	    ->addFieldToFilter('class_name', $class_name)
	    ->load()
	    ->getFirstItem();

	    if(empty($productTaxClass->getData())){
	    	return false;
	    } else{
	    	return true;
	    }
	}

	/**
	  Create new tax

	  @param int $rate Tax rate
	  @return Product tax class id
	 */
	function createTaxClass($rate){
		if(!taxClassExistenceCheck($rate)){
			//get the product tax class
			$productTaxClass = Mage::getModel('tax/class')
			    ->setData(array(
			    	"class_type"	=> "PRODUCT",
					"class_name"	=> "BTW_".$rate
			    ))->save();

			//get the customer tax class
			$customerTaxClass = Mage::getModel('tax/class')
			    ->getCollection()
			    ->addFieldToFilter('class_name', 'Retail Customer')
			    ->load()
			    ->getFirstItem();

			//create a new Dutch tax rate/zone
			$taxCalculationRateNl = Mage::getModel('tax/calculation_rate')
			    ->setData(array(
			        "code"                  => "BTW_NL_".$rate,
			        "tax_country_id"        => "NL",
			        "tax_region_id"         => "0",
			        "zip_is_range"          => "0",
			        "tax_postcode"          => "*",
			        "rate"                  => $rate,
			    ))->save();

			    //create a new English tax rate/zone
			$taxCalculationRateEng = Mage::getModel('tax/calculation_rate')
			    ->setData(array(
			        "code"                  => "BTW_GB_".$rate,
			        "tax_country_id"        => "GB",
			        "tax_region_id"         => "0",
			        "zip_is_range"          => "0",
			        "tax_postcode"          => "*",
			        "rate"                  => $rate,
			    ))->save();

			//create a new tax rule
			$ruleModel = Mage::getModel('tax/calculation_rule')
			    ->setData(array(
			        "code"                  => "BTW_".$rate,
			        "tax_customer_class"    => array($customerTaxClass->getId()),
			        "tax_product_class"     => array($productTaxClass->getId()),
			        "tax_rate"              => array($taxCalculationRateNl->getId(),$taxCalculationRateNl->getId()),
			        "priority"              => "0",
			        "position"              => "0",
			    ))->save();

			return $productTaxClass->getId();
		} else{
			//Return existing tax class id
			return $productTaxClass = Mage::getModel('tax/class')
			->getCollection()
		    ->addFieldToFilter('class_name', "BTW_".$rate)
		    ->load()
		    ->getFirstItem()
		    ->getId();
		}
	}

	function updateVariationPrice($product, $price, $value_index){
	    $resource = Mage::getSingleton('core/resource');			//Resource model
	    $writeConnection = $resource->getConnection('core_write');	//Write connection
	    $productId = 44;											//Productid

	    /**
	       Set new variation price
	     */
	    $query = "UPDATE catalog_product_super_attribute_pricing SET pricing_value = '{$price}' WHERE product_super_attribute_id = (SELECT product_super_attribute_id FROM catalog_product_super_attribute WHERE product_id = '{$product}') AND value_index = ('$value_index')";

	    $writeConnection->query($query);							//Excecute query
	}

	function createVariationPrice($product, $price, $value_index){
	    $resource = Mage::getSingleton('core/resource');			//Resource model
	    $writeConnection = $resource->getConnection('core_write');	//Write connection
	    $productId = 44;											//Productid

	    /**
	       Set new variation price
	     */
	    $query = "INSERT INTO catalog_product_super_attribute_pricing (product_super_attribute_id, value_index, is_percent, pricing_value, website_id) SELECT product_super_attribute_id, '{$value_index}', 0, 0, 0 FROM catalog_product_super_attribute WHERE product_id = '{$product}'";
	    $writeConnection->query($query);							//Excecute query
	}
?>
