<?PHP
/**
 * @version 1.0
 * @copyright Key2Publish
 * @author Jordy Nieland
 */

	/**
	  Get Magento class
	  This makes it possible to call Magento its functions
	 */
	function getMagento(){
		require './app/Mage.php';
		Mage::init();
	}

	/**
	  Get categories from SQLITE file

	  @param PDO $db Sqlite database instance
	  @param int $START Start of post
	  @param int $STEPS Steps per post
	  @return array $categories Contains categories
	 */
	function getCategoriesSqlite($db, $START, $STEPS){
		$categories = array();
		if($START !== null && $STEPS !== null){
			$query = $db->query("SELECT * FROM groups ORDER BY k2_parent LIMIT ".$START.", ".$STEPS.";");
		} else{
			$query = $db->query("SELECT * FROM groups ORDER BY k2_parent;");
		}

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$categories[$result['k2_id']] = $result;
		}

		return $categories;
	}

	/**
	  Get datatypes from sqlite

	  @param PDO $db Sqlite database instance
	  @return String $type Contains product type (configurable or simple)
	 */
	function getDatatype($db){
		$count = 0;
		try{
			$query = $db->query("SELECT tbl_name FROM sqlite_master WHERE tbl_name='productgroups';");
			$result = $query->fetch(PDO::FETCH_ASSOC);
		} catch(Exception $e){

		}

		if($result != null){
			$type = 'configurable';
		} else{
			$type = 'simple';
		}

		return $type;
	}

	/**
	  Get products from sqlite

	  @param PDO $db Instance of sqlite database
	  @param String $type Product type
	  @param int $START Start of post (steps incremented)
	  @param int $STEPS Amount of steps per post
	  @return array $products Contains products in an array
	 */
	function getProductsSqlite($db, $type, $START, $STEPS){
		$products = array();

		if($type == 'both'){
			$query = $db->query("SELECT * FROM productgroups LIMIT ".$START.", ".$STEPS.";");
			$query2 = $db->query("SELECT * FROM productgroups WHERE k2_id NOT IN (SELECT k2_parent FROM products)");	//Get simple products

			while($result = $query2->fetch(PDO::FETCH_ASSOC)){
				$products[] = $result;
			}

		} else if($type == 'configurable'){
			$query = $db->query("SELECT * FROM productgroups LIMIT ".$START.", ".$STEPS.";");
		} else{
			//echo "SELECT k2_id, k2_parent, k2_productid, k2_name, k2_description, k2_picture, k2_price, k2_vat FROM products LIMIT ".$START.", ".$STEPS.";";
			$query = $db->query("SELECT * FROM products LIMIT ".$START.", ".$STEPS.";");
		}

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$products[] = $result;
		}

		return $products;
	}

	function getParentsSqlite($db){
		$query = $db->query("SELECT G.k2_id as Gname, P.k2_name as Pname FROM products P, groups G WHERE P.k2_parent = G.k2_id");

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$products[$result['Pname']][] = $result['Gname'];
		}

		return $products;
	}

	/**
	  Get stores from Magento
	 */
	function getStores(){
		$allStores = Mage::app()->getStores();
		foreach ($allStores as $_eachStoreId => $val){
			//$store_code = Mage::app()->getStore($_eachStoreId)->getCode();
			$store_name = Mage::app()->getStore($_eachStoreId)->getName();
			$store_id = Mage::app()->getStore($_eachStoreId)->getId();
			$stores[] = '{"stores":[{"store_id":'.$store_id.',"name":"'.$store_name.'"}]}';
		}

		echo implode(', ', $stores);
	}

	/**
	  Get languages from Magento
	 */
	function getLanguages(){
		$language_collection = Mage::app()->getLocale()->getOptionLocales();
		foreach($language_collection as $language){
			$languages[] = '"'.$language['value'].'":{"code":"'.$language['value'].'","name":"'.$language['label'].'"}';
		}

		echo '{"languages":{';
		print_r($languages);
		echo '}}';
	}

	/**
	  Get options from sqlite

	  @param PDO $db Instance of sqlite database
	  @return array $options Array of options (from datatypes)
	 */
	function getOptionSqlite($db){
		$query = $db->query("SELECT * FROM datatypes WHERE k2_type='Options' GROUP BY k2_value;");
		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$options[] = $result;
		}
		return $options;
	}

	/**
	  Get attribute options from sqlite

	  @param PDO $db Instance of sqlite database
	  @return array $datatypes Array of datatypes (attributes)
	 */
	function getAllAttributeOptions($db){
		$query = $db->query("SELECT * FROM datatypes WHERE k2_type='Options';");
		if ($query) {
		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$datatypes[$result['k2_id']]['0'] = $result['k2_name'];
			$datatypes[$result['k2_id']]['1'] = $result['k2_value'];
		}
		return $datatypes;
		}
	}

	/**
	  Get children indexed by parent product from sqlite

	  @param $db
	  @return $index
	 */
	function getChildrenBySuperIndex($db){
		$query = $db->query("SELECT * FROM products;");
		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$index[$result['k2_parent']][$result['k2_productid']] = $result;
		}

		return $index;
	}

	function getSimpleAttributes($db){
			$query = $db->query("SELECT * FROM datatypes WHERE k2_type='Data';");
			if ($query) {
				while($result = $query->fetch(PDO::FETCH_ASSOC)){
					$index[$result['k2_index']][] = $result;
				}
			}

			return $index;
	}

	/**
	  Get manufacturers from sqlite

	  @param PDO $db Instance of sqlite database
	  @return array $index Get Manufacturers from sqlite database
	 */
	function getManufacturers($db){
		$query = $db->query("SELECT * FROM datatypes WHERE k2_type='Manufacturer';");
		$index = array();

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			if(!$index['name']){
				$index['name'] = $result['k2_name'];
			}

			$index[$result['k2_id']] = $result['k2_value'];
		}

		return $index;
	}

	/**
	  Get attributes from sqlite

	  @param PDO $db Instance of sqlite database
	  @return array $index Array with attributes from sqlite database
	 */
	function getAttributes($db){
		$query = $db->query("SELECT * FROM datatypes WHERE k2_type != 'Data';");
		if ($query) {
			while($result = $query->fetch(PDO::FETCH_ASSOC)){
				$index[$result['k2_id']][] = $result;

				if(!in_array($result['k2_name'], $index['attributes'])){
					$index['attributes'][] = $result;
				}
			}
		}
		return $index;
	}

	/**
	  Get categorie paths from sqlite

	  @param PDO $db Instance of sqlite database
	  @return array $paths contains path of categories
	 */
	function getCategorieTree($db){
		$paths = array();
		$parents = array();
		$query = $db->query("SELECT * FROM groups ORDER BY k2_parent;");

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$categories[$result['k2_id']] = $result;
			$parents[$result['k2_id']] = $result['k2_parent'];
		}

		foreach($categories as $id => $categorie){
			$boole = false;
			$x = 0;
			while($boole == false){
				$x++;
				if($paths[$id][sizeof($paths[$id]) - 1] <= 0){
					$last = $id;
				}

				if($parents[$last] == 0){
					$paths[$id] = array_reverse($paths[$id]);
					$boole = true;
				} else if ($id != $parents[$last]){
					$paths[$id][] = $parents[$last];
					$last = $parents[$last];
				}

				if($x>1000){
					echo "ERROR: Deadlock on id: $id";
					break;
				}
			}
		}

		return $paths;
	}

	/**
	 * Get amount of products
	 *
	 * @return sizeOf($products)
	 */
	function countProductsSqlite($db){
		$query = $db->query("SELECT * FROM products");

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
			$products[] = $result;
		}

		return count($products);
	}

	function getCategoryStringPath($db, $categories){
		$query = $db->query("SELECT * FROM groups");
		$string_paths = array();

		while($result = $query->fetch(PDO::FETCH_ASSOC)){
      if($result['k2_name'] != ""){
			     $string_paths[$result['k2_id']][] = $result['k2_name'];
      }
			if($result['k2_parent'] != 0){
        if($categories[$result['k2_parent']]['k2_name']){
				  $string_paths[$result['k2_id']][] = $categories[$result['k2_parent']]['k2_name'];
        }
				$parent = $result['k2_parent'];
				while($categories[$parent]['k2_parent'] != 0){
          if($categories[$parent]['k2_name']){
					  $string_paths[$result['k2_id']][] = $categories[$parent]['k2_name'];
          }
					$parent = $categories[$parent]['k2_id'];
				}
				$string_paths[$result['k2_id']] = array_reverse($string_paths[$result['k2_id']]);
			}
		}

		//print_r($string_paths);
		return $string_paths;

	}
?>
